# btc2fiat

All I wanted was a script that can print the last known price of Bitcoin on various exchanges. And I didn't find any of that on GitHub. So I did it myself.

## JS

`npm run build`

`npm publish jsdist`
